@@ -8,18 +8,18 @@ Use it like::
 """
 
 from . import sg_default_entities as sde
-from .core import new_entity  # noqa: F401
-from .core import new_site  # noqa: F401
 from .core import (
+    new_entity,  # noqa: F401
+    new_site,  # noqa: F401
     register_fallback_pysg_class,
     register_pysg_class,
     register_sg_site_class,
 )
 from .sg_entity import Field, SGEntity  # noqa: F401
-from .sg_site import SGSite  # noqa: F401
+from .sg_site import SGSite
 
 #: The pyshotgrid version number as string
-VERSION = "0.8.0"
+VERSION = "0.9.1"
 
 register_sg_site_class(SGSite)
 register_fallback_pysg_class(SGEntity)
