@@ -1,5 +1,5 @@
 from .core import convert_fields_to_dicts, convert_fields_to_pysg, new_entity, new_site
-from .field import Field
+from .field import Field, FieldSchema
 
 
 class SGEntity(object):
@@ -75,6 +75,28 @@ class SGEntity(object):
         """
         return "{}/detail/{}/{}".format(self.sg.base_url, self._type, self._id)
 
+    def __eq__(self, other):
+        """
+        Compare SGEntities against each other.
+        We consider the entities equal if all these are true:
+          - the other instance is a (sub-)class of SGEntity
+          - the ID's match
+          - the entity types match
+          - the base URL of the Shotgun instances is the same.
+
+        :param Any other: The other python object to compare to.
+        :return: Whether the 2 instances represent the same entity in ShotGrid.
+        :rtype: bool
+        """
+        return all(
+            (
+                isinstance(other, SGEntity),
+                self._id == other.id,
+                self._type == other.type,
+                self._sg.base_url == other.sg.base_url,
+            )
+        )
+
     def __getitem__(self, field):
         """
         Enabling dict notation to query fields of the entity from ShotGrid.
@@ -226,8 +248,12 @@ class SGEntity(object):
     def field_schemas(self):
         """
         :return: The schemas of all the entity fields.
+        :rtype: dict[str,FieldSchema]
         """
-        return self.sg.schema_field_read(self._type)
+        return {
+            field: FieldSchema(self._sg, self._type, field)
+            for field in self.sg.schema_field_read(self._type)
+        }
 
     def _publishes(
         self, base_filter=None, pub_types=None, latest=False, additional_sg_filter=None
